==> voreen-src-4.4-win.zip: voreen-src-4.4-win/src/core/properties/optionproperty.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "voreen/core/properties/optionproperty.h"

namespace voreen {

template<>
void Option<int>::serialize(XmlSerializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
}

template<>
void Option<int>::deserialize(XmlDeserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
}

template<>
void Option<float>::serialize(XmlSerializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
}

template<>
void Option<float>::deserialize(XmlDeserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
}

template<>
void Option<GLenum>::serialize(XmlSerializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
}

template<>
void Option<GLenum>::deserialize(XmlDeserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
}

template<>
void Option<std::string>::serialize(XmlSerializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
}

template<>
void Option<std::string>::deserialize(XmlDeserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
}

// ============================================================================

}   // namespace

==> voreen-src-5.0.1-win.zip: voreen-src-5.0.1-win/src/core/properties/optionproperty.cpp <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2018 University of Muenster, Germany,                        *
 * Department of Computer Science.                                                 *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#include "voreen/core/properties/optionproperty.h"

namespace voreen {

template<>
void Option<int>::serialize(Serializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
    s.serialize("GuiColor", guiColor_);
}

template<>
void Option<int>::deserialize(Deserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
    s.optionalDeserialize("GuiColor",guiColor_,tgt::col4::zero);
}

template<>
void Option<float>::serialize(Serializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
    s.serialize("GuiColor", guiColor_);
}

template<>
void Option<float>::deserialize(Deserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
    s.optionalDeserialize("GuiColor",guiColor_,tgt::col4::zero);
}

template<>
void Option<GLenum>::serialize(Serializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
    s.serialize("GuiColor", guiColor_);
}

template<>
void Option<GLenum>::deserialize(Deserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
    s.optionalDeserialize("GuiColor",guiColor_,tgt::col4::zero);
}

template<>
void Option<std::string>::serialize(Serializer& s) const {
    s.serialize("Key", key_);
    s.serialize("Description", description_);
    s.serialize("Value", value_);
    s.serialize("GuiColor", guiColor_);
}

template<>
void Option<std::string>::deserialize(Deserializer& s) {
    s.deserialize("Key", key_);
    s.deserialize("Description", description_);
    s.deserialize("Value", value_);
    s.optionalDeserialize("GuiColor",guiColor_,tgt::col4::zero);
}

// ============================================================================

}   // namespace
